@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.2.5';
+our $VERSION = '0.2.6';
 
 1;
 
@@ -1017,6 +1017,95 @@ For example:
     $ export SPARROW_ROOT=/opt/sparrow
 
 
+=head1 Remote Tasks
+
+B<I<WARNING!>> This feature is quite experimental and should be tested.
+
+Remote tasks are sparrow tasks SparrowHub users could I<bind> to theirs accounts:
+
+    $ sparrow project create utils
+    
+    $ sparrow task add utils  git-setup git-base
+    
+    $ sparrow task ini utils git-setup 
+    
+      email melezhik@gmail.com 
+      name  'Alexey Melezhik'
+     
+    $ sparrow task run utils git-setup
+
+Ok, now we could "wrap" our task and upload to our account:
+
+    $ sparrow remote task upload utils/git-setup
+
+B<I<NOTE!>> to upload remote task you need a SparrowHub account.
+
+Then I ssh-ing to another server to re-apply my git configuration:
+
+    $ ssh some-other-host
+    $ sparrow remote task install utils/git-setup
+
+Now I can:
+
+    $ sparrow task run utils git-setup
+
+Pretty cool, huh? :)))
+
+A shortcut for C<sparrow remote task install ... & sparrow task run> is:
+
+    $ sparrow remote task task run utils/git-setup
+
+
+=head2 Share your task
+
+I<By default> remote task uploaded to SparrowHub is only accessible by task author. This is so called
+private remote task. What if you want to share some fun stuff with people? - I<Share> your task:
+
+    $ sparrow remote task share utils/nano-rc
+
+Now users can use your remote task:
+
+    $ sparrow remote task install melezhik@utils/nano-rc
+    $ sparrow task run utils utils nano-rc
+
+or using shortcut in single step:
+
+    $ sparrow remote task run melezhik@utils/nano-rc
+
+B<I<NOTE!>> you don't need a SparrowHub account to use public remote tasks, even unregisters users can use
+public remote tasks.
+
+
+=head2 Hide your task
+
+Want to hide your task again? Not a problem:
+
+    $ sparrow remote task hide app/passwords
+
+Now only you can use app/passwords task.
+
+
+=head2 List remote tasks
+
+To list your remote tasks ( both private and public ) say this:
+
+    $ sparrow remote task list
+
+
+=head2 List public tasks
+
+To get a list of available public remote tasks say this:
+
+    $ sparrow remote task public-list
+
+
+=head2 Remove remote task
+
+And finaly you can remove remote task:
+
+    $ sparrow remote task remove app/old-stuff
+
+
 =head1 AUTHOR
 
 L<Aleksei Melezhik|mailto:melezhik@gmail.com>
